## Lite-BO: a lite Bayesian Optimization Library.
This repository partially or totally comes from [SMAC3](https://github.com/automl/SMAC3).
Different from SMAC3, lite-bo supports MacOS, Windows and Linux platforms.
